@@ -1,5 +1,6 @@
 FAMD <- function (base, ncp = 5, graph = TRUE,sup.var=NULL, ind.sup = NULL, axes=c(1,2),row.w=NULL,tab.comp=NULL){
     base <- as.data.frame(base)
+	base <- droplevels(base)
     type=NULL
     for (v in 1:ncol(base)) {
       if (!is.numeric(base[,v])) type=c(type,"n")
@@ -9,7 +10,7 @@ FAMD <- function (base, ncp = 5, graph = TRUE,sup.var=NULL, ind.sup = NULL, axes
     if (!any("s"%in%type)) warning("All your variables are qualitative: you should make MCA")
     resultats <- MFA(base=base, group = rep(1,ncol(base)), type=type, name.group = colnames(base), num.group.sup = sup.var, ind.sup = ind.sup, graph=FALSE, ncp = ncp,row.w=row.w,tab.comp=tab.comp)
     class(resultats) <- c("MFA", "list")
-    if (graph){
+    if (graph & (ncp>1)){
       if (any("n"%in%type)) plot(resultats,choix="ind", axes=axes,habillage="none")
       if (any("c"%in%type)|any("s"%in%type)) plot(resultats,choix="var",axes=axes)
       plot(resultats,choix="ind",invisible=c("quali","quali.sup"), axes=axes,habillage="none",new.plot=TRUE)
